/*
 * Copyright (C) Prof. Martin Breunig
 */

package de.uos.igf.db3d.dbms.api;

import java.util.TreeMap;

/**
 * A list of EPSG (European Petroluem Survey Group) SRID codes and names
 * (projection and datum).
 * 
 * SRID list found on http://inovagis.terradue.com/giserver/epsg.asp
 * 
 * @author Edgar Butwilowski
 */
public final class SRID {

	private static final TreeMap<Integer, String> SRID = new TreeMap<Integer, String>();

	static {

		SRID.put(4123, "KKJ");
		SRID.put(4131, "Indian 1960");
		SRID.put(4201, "Adindan");
		SRID.put(4202, "AGD66");
		SRID.put(4203, "AGD84");
		SRID.put(4204, "Ain el Abd");
		SRID.put(4205, "Afgooye");
		SRID.put(4209, "Arc 1950");
		SRID.put(4210, "Arc 1960");
		SRID.put(4216, "Bermuda 1957");
		SRID.put(4219, "Bukit Rimpah");
		SRID.put(4221, "Campo Inchauspe");
		SRID.put(4222, "Cape");
		SRID.put(4223, "Carthage");
		SRID.put(4225, "Corrego Alegre");
		SRID.put(4230, "Datum Europeu Internacional ED50");
		SRID.put(4237, "HD72");
		SRID.put(4238, "ID74");
		SRID.put(4239, "Indian 1954");
		SRID.put(4240, "Indian 1975");
		SRID.put(4244, "Kandawala");
		SRID.put(4250, "Leigon");
		SRID.put(4255, "Herat North");
		SRID.put(4256, "Mahe 1971");
		SRID.put(4258, "ETRS89");
		SRID.put(4261, "Merchich");
		SRID.put(4262, "Massawa");
		SRID.put(4263, "Minna");
		SRID.put(4267, "NAD27");
		SRID.put(4269, "NAD83");
		SRID.put(4274, "Datum 73 de Lisboa");
		SRID.put(4277, "OSGB 1936");
		SRID.put(4284, "Pulkovo 1942");
		SRID.put(4287, "Qornoq");
		SRID.put(4291, "SAD69");
		SRID.put(4292, "Sapper Hill 1943");
		SRID.put(4293, "Schwarzeck");
		SRID.put(4298, "Timbalai 1948");
		SRID.put(4301, "Tokyo");
		SRID.put(4307, "Nord Sahara 1959");
		SRID.put(4309, "Yacare");
		SRID.put(4311, "Zanderij");
		SRID.put(4312, "MGI");
		SRID.put(4322, "WGS 72");
		SRID.put(4324, "WGS 72BE");
		SRID.put(4326, "WGS84 (World Geodesic Datum)");
		SRID.put(4803, "Datum Geodésico Hayford de Lisboa");
		SRID.put(4807, "NTF (Paris)");
		SRID.put(20004, "Pulkovo 1995 / Gauss-Kruger zone 4");
		SRID.put(20005, "Pulkovo 1995 / Gauss-Kruger zone 5");
		SRID.put(20006, "Pulkovo 1995 / Gauss-Kruger zone 6");
		SRID.put(20007, "Pulkovo 1995 / Gauss-Kruger zone 7");
		SRID.put(20008, "Pulkovo 1995 / Gauss-Kruger zone 8");
		SRID.put(20009, "Pulkovo 1995 / Gauss-Kruger zone 9");
		SRID.put(20010, "Pulkovo 1995 / Gauss-Kruger zone 10");
		SRID.put(20011, "Pulkovo 1995 / Gauss-Kruger zone 11");
		SRID.put(20012, "Pulkovo 1995 / Gauss-Kruger zone 12");
		SRID.put(20013, "Pulkovo 1995 / Gauss-Kruger zone 13");
		SRID.put(20014, "Pulkovo 1995 / Gauss-Kruger zone 14");
		SRID.put(20015, "Pulkovo 1995 / Gauss-Kruger zone 15");
		SRID.put(20016, "Pulkovo 1995 / Gauss-Kruger zone 16");
		SRID.put(20017, "Pulkovo 1995 / Gauss-Kruger zone 17");
		SRID.put(20018, "Pulkovo 1995 / Gauss-Kruger zone 18");
		SRID.put(20019, "Pulkovo 1995 / Gauss-Kruger zone 19");
		SRID.put(20020, "Pulkovo 1995 / Gauss-Kruger zone 20");
		SRID.put(20021, "Pulkovo 1995 / Gauss-Kruger zone 21");
		SRID.put(20022, "Pulkovo 1995 / Gauss-Kruger zone 22");
		SRID.put(20023, "Pulkovo 1995 / Gauss-Kruger zone 23");
		SRID.put(20024, "Pulkovo 1995 / Gauss-Kruger zone 24");
		SRID.put(20025, "Pulkovo 1995 / Gauss-Kruger zone 25");
		SRID.put(20026, "Pulkovo 1995 / Gauss-Kruger zone 26");
		SRID.put(20027, "Pulkovo 1995 / Gauss-Kruger zone 27");
		SRID.put(20028, "Pulkovo 1995 / Gauss-Kruger zone 28");
		SRID.put(20029, "Pulkovo 1995 / Gauss-Kruger zone 29");
		SRID.put(20030, "Pulkovo 1995 / Gauss-Kruger zone 30");
		SRID.put(20031, "Pulkovo 1995 / Gauss-Kruger zone 31");
		SRID.put(20032, "Pulkovo 1995 / Gauss-Kruger zone 32");
		SRID.put(20064, "Pulkovo 1995 / Gauss-Kruger 4N");
		SRID.put(20065, "Pulkovo 1995 / Gauss-Kruger 5N");
		SRID.put(20066, "Pulkovo 1995 / Gauss-Kruger 6N");
		SRID.put(20067, "Pulkovo 1995 / Gauss-Kruger 7N");
		SRID.put(20068, "Pulkovo 1995 / Gauss-Kruger 8N");
		SRID.put(20069, "Pulkovo 1995 / Gauss-Kruger 9N");
		SRID.put(20070, "Pulkovo 1995 / Gauss-Kruger 10N");
		SRID.put(20071, "Pulkovo 1995 / Gauss-Kruger 11N");
		SRID.put(20072, "Pulkovo 1995 / Gauss-Kruger 12N");
		SRID.put(20073, "Pulkovo 1995 / Gauss-Kruger 13N");
		SRID.put(20074, "Pulkovo 1995 / Gauss-Kruger 14N");
		SRID.put(20075, "Pulkovo 1995 / Gauss-Kruger 15N");
		SRID.put(20076, "Pulkovo 1995 / Gauss-Kruger 16N");
		SRID.put(20077, "Pulkovo 1995 / Gauss-Kruger 17N");
		SRID.put(20078, "Pulkovo 1995 / Gauss-Kruger 18N");
		SRID.put(20079, "Pulkovo 1995 / Gauss-Kruger 19N");
		SRID.put(20080, "Pulkovo 1995 / Gauss-Kruger 20N");
		SRID.put(20081, "Pulkovo 1995 / Gauss-Kruger 21N");
		SRID.put(20082, "Pulkovo 1995 / Gauss-Kruger 22N");
		SRID.put(20083, "Pulkovo 1995 / Gauss-Kruger 23N");
		SRID.put(20084, "Pulkovo 1995 / Gauss-Kruger 24N");
		SRID.put(20085, "Pulkovo 1995 / Gauss-Kruger 25N");
		SRID.put(20086, "Pulkovo 1995 / Gauss-Kruger 26N");
		SRID.put(20087, "Pulkovo 1995 / Gauss-Kruger 27N");
		SRID.put(20088, "Pulkovo 1995 / Gauss-Kruger 28N");
		SRID.put(20089, "Pulkovo 1995 / Gauss-Kruger 29N");
		SRID.put(20090, "Pulkovo 1995 / Gauss-Kruger 30N");
		SRID.put(20091, "Pulkovo 1995 / Gauss-Kruger 31N");
		SRID.put(20092, "Pulkovo 1995 / Gauss-Kruger 32N");
		SRID.put(22391, "Carthage / Nord Tunisie");
		SRID.put(22392, "Carthage / Sud Tunisie");
		SRID.put(26191, "Merchich / Nord Maroc");
		SRID.put(26192, "Merchich / Sud Maroc");
		SRID.put(26193, "Merchich / Sahara");
		SRID.put(30491, "Voirol 1875 / Nord Algerie (ancienne)");
		SRID.put(30492, "Voirol 1875 / Sud Algerie (ancienne)");
		SRID.put(30591, "Voirol Unifie / Nord Algerie");
		SRID.put(30592, "Voirol Unifie / Sud Algerie");
		SRID.put(20137, "Adindan / UTM zone 37N");
		SRID.put(20138, "Adindan / UTM zone 38N");
		SRID.put(20248, "AGD66 / AMG zone 48");
		SRID.put(20249, "AGD66 / AMG zone 49");
		SRID.put(20250, "AGD66 / AMG zone 50");
		SRID.put(20251, "AGD66 / AMG zone 51");
		SRID.put(20252, "AGD66 / AMG zone 52");
		SRID.put(20253, "AGD66 / AMG zone 53");
		SRID.put(20254, "AGD66 / AMG zone 54");
		SRID.put(20255, "AGD66 / AMG zone 55");
		SRID.put(20256, "AGD66 / AMG zone 56");
		SRID.put(20257, "AGD66 / AMG zone 57");
		SRID.put(20258, "AGD66 / AMG zone 58");
		SRID.put(20348, "AGD84 / AMG zone 48");
		SRID.put(20349, "AGD84 / AMG zone 49");
		SRID.put(20350, "AGD84 / AMG zone 50");
		SRID.put(20351, "AGD84 / AMG zone 51");
		SRID.put(20352, "AGD84 / AMG zone 52");
		SRID.put(20353, "AGD84 / AMG zone 53");
		SRID.put(20354, "AGD84 / AMG zone 54");
		SRID.put(20355, "AGD84 / AMG zone 55");
		SRID.put(20356, "AGD84 / AMG zone 56");
		SRID.put(20357, "AGD84 / AMG zone 57");
		SRID.put(20358, "AGD84 / AMG zone 58");
		SRID.put(20437, "Ain el Abd / UTM zone 37N");
		SRID.put(20438, "Ain el Abd / UTM zone 38N");
		SRID.put(20439, "Ain el Abd / UTM zone 39N");
		SRID.put(20499, "Ain el Abd / Bahrain Grid");
		SRID.put(20538, "Afgooye / UTM zone 38N");
		SRID.put(20539, "Afgooye / UTM zone 39N");
		SRID.put(20790, "Lisbon (Lisbon)/Portuguese National Grid");
		SRID.put(20822, "Aratu / UTM zone 22S");
		SRID.put(20823, "Aratu / UTM zone 23S");
		SRID.put(20824, "Aratu / UTM zone 24S");
		SRID.put(20934, "Arc 1950 / UTM zone 34S");
		SRID.put(20935, "Arc 1950 / UTM zone 35S");
		SRID.put(20936, "Arc 1950 / UTM zone 36S");
		SRID.put(2100, "GGRS87 / Greek Grid");
		SRID.put(21035, "Arc 1960 / UTM zone 35S");
		SRID.put(21036, "Arc 1960 / UTM zone 36S");
		SRID.put(21037, "Arc 1960 / UTM zone 37S");
		SRID.put(21095, "Arc 1960 / UTM zone 35N");
		SRID.put(21096, "Arc 1960 / UTM zone 36N");
		SRID.put(21097, "Arc 1960 / UTM zone 37N");
		SRID.put(21148, "Batavia / UTM zone 48S");
		SRID.put(21149, "Batavia / UTM zone 49S");
		SRID.put(21150, "Batavia / UTM zone 50S");
		SRID.put(21413, "Beijing 1954 / Gauss-Kruger zone 13");
		SRID.put(21414, "Beijing 1954 / Gauss-Kruger zone 14");
		SRID.put(21415, "Beijing 1954 / Gauss-Kruger zone 15");
		SRID.put(21416, "Beijing 1954 / Gauss-Kruger zone 16");
		SRID.put(21417, "Beijing 1954 / Gauss-Kruger zone 17");
		SRID.put(21418, "Beijing 1954 / Gauss-Kruger zone 18");
		SRID.put(21419, "Beijing 1954 / Gauss-Kruger zone 19");
		SRID.put(21420, "Beijing 1954 / Gauss-Kruger zone 20");
		SRID.put(21421, "Beijing 1954 / Gauss-Kruger zone 21");
		SRID.put(21422, "Beijing 1954 / Gauss-Kruger zone 22");
		SRID.put(21423, "Beijing 1954 / Gauss-Kruger zone 23");
		SRID.put(21473, "Beijing 1954 / Gauss-Kruger 13N");
		SRID.put(21474, "Beijing 1954 / Gauss-Kruger 14N");
		SRID.put(21475, "Beijing 1954 / Gauss-Kruger 15N");
		SRID.put(21476, "Beijing 1954 / Gauss-Kruger 16N");
		SRID.put(21477, "Beijing 1954 / Gauss-Kruger 17N");
		SRID.put(21478, "Beijing 1954 / Gauss-Kruger 18N");
		SRID.put(21479, "Beijing 1954 / Gauss-Kruger 19N");
		SRID.put(21480, "Beijing 1954 / Gauss-Kruger 20N");
		SRID.put(21481, "Beijing 1954 / Gauss-Kruger 21N");
		SRID.put(21482, "Beijing 1954 / Gauss-Kruger 22N");
		SRID.put(21483, "Beijing 1954 / Gauss-Kruger 23N");
		SRID.put(21817, "Bogota / UTM zone 17N");
		SRID.put(21818, "Bogota / UTM zone 18N");
		SRID.put(21891, "Bogota / Colombia West zone");
		SRID.put(21892, "Bogota / Colombia Bogota zone");
		SRID.put(21893, "Bogota / Colombia East Central zone");
		SRID.put(21894, "Bogota / Colombia East");
		SRID.put(22032, "Camacupa / UTM zone 32S");
		SRID.put(22033, "Camacupa / UTM zone 33S");
		SRID.put(22091, "Camacupa / TM 11.30 SE");
		SRID.put(22092, "Camacupa / TM 12 SE");
		SRID.put(2219, "ATS77 / UTM zone 19N");
		SRID.put(22191, "Campo Inchauspe / Argentina 1");
		SRID.put(22192, "Campo Inchauspe / Argentina 2");
		SRID.put(22193, "Campo Inchauspe / Argentina 3");
		SRID.put(22194, "Campo Inchauspe / Argentina 4");
		SRID.put(22195, "Campo Inchauspe / Argentina 5");
		SRID.put(22196, "Campo Inchauspe / Argentina 6");
		SRID.put(22197, "Campo Inchauspe / Argentina 7");
		SRID.put(2220, "ATS77 / UTM zone 20N");
		SRID.put(22234, "Cape / UTM zone 34S");
		SRID.put(22235, "Cape / UTM zone 35S");
		SRID.put(22236, "Cape / UTM zone 36S");
		SRID.put(22332, "Carthage / UTM zone 32N");
		SRID.put(22523, "Corrego Alegre / UTM zone 23S");
		SRID.put(22524, "Corrego Alegre / UTM zone 24S");
		SRID.put(22832, "Douala / UTM zone 32N");
		SRID.put(2294, "ATS77 / MTM Nova Scotia zone 4");
		SRID.put(2295, "ATS77 / MTM Nova Scotia zone 5");
		SRID.put(22992, "Egypt 1907 / Red Belt");
		SRID.put(22993, "Egypt 1907 / Purple Belt");
		SRID.put(22994, "Egypt 1907 / Extended Purple Belt");
		SRID.put(23028, "ED50 / UTM zone 28N");
		SRID.put(23029, "ED50 / UTM zone 29N");
		SRID.put(23030, "ED50 / UTM zone 30N");
		SRID.put(23031, "ED50 / UTM zone 31N");
		SRID.put(23032, "ED50 / UTM zone 32N");
		SRID.put(23033, "ED50 / UTM zone 33N");
		SRID.put(23034, "ED50 / UTM zone 34N");
		SRID.put(23035, "ED50 / UTM zone 35N");
		SRID.put(23036, "ED50 / UTM zone 36N");
		SRID.put(23037, "ED50 / UTM zone 37N");
		SRID.put(23038, "ED50 / UTM zone 38N");
		SRID.put(23090, "ED50 / TM 0 N");
		SRID.put(23095, "ED50 / TM 5 NE");
		SRID.put(23239, "Fahud / UTM zone 39N");
		SRID.put(23240, "Fahud / UTM zone 40N");
		SRID.put(23433, "Garoua / UTM zone 33N");
		SRID.put(23846, "ID74 / UTM zone 46N");
		SRID.put(23847, "ID74 / UTM zone 47N");
		SRID.put(23848, "ID74 / UTM zone 48N");
		SRID.put(23849, "ID74 / UTM zone 49N");
		SRID.put(23850, "ID74 / UTM zone 50N");
		SRID.put(23851, "ID74 / UTM zone 51N");
		SRID.put(23852, "ID74 / UTM zone 52N");
		SRID.put(23853, "ID74 / UTM zone 53N");
		SRID.put(23886, "ID74 / UTM zone 46S");
		SRID.put(23887, "ID74 / UTM zone 47S");
		SRID.put(23888, "ID74 / UTM zone 48S");
		SRID.put(23889, "ID74 / UTM zone 49S");
		SRID.put(23890, "ID74 / UTM zone 50S");
		SRID.put(23891, "ID74 / UTM zone 51S");
		SRID.put(23892, "ID74 / UTM zone 52S");
		SRID.put(23893, "ID74 / UTM zone 53S");
		SRID.put(23894, "ID74 / UTM zone 54S");
		SRID.put(2391, "KKJ / Finland zone 1");
		SRID.put(2392, "KKJ / Finland zone 2");
		SRID.put(2393, "KKJ / Finland Uniform Coordinate System");
		SRID.put(2394, "KKJ / Finland zone 4");
		SRID.put(23946, "Indian 1954 / UTM zone 46N");
		SRID.put(23947, "Indian 1954 / UTM zone 47N");
		SRID.put(23948, "Indian 1954 / UTM zone 48N");
		SRID.put(2400, "RT90 2.5 gon W");
		SRID.put(24047, "Indian 1975 / UTM zone 47N");
		SRID.put(24048, "Indian 1975 / UTM zone 48N");
		SRID.put(24547, "Kertau / UTM zone 47N");
		SRID.put(24548, "Kertau / UTM zone 48N");
		SRID.put(24720, "La Canoa / UTM zone 20N");
		SRID.put(24721, "La Canoa / UTM zone 21N");
		SRID.put(24818, "PSAD56 / UTM zone 18N");
		SRID.put(24819, "PSAD56 / UTM zone 19N");
		SRID.put(24820, "PSAD56 / UTM zone 20N");
		SRID.put(24821, "PSAD56 / UTM zone 21N");
		SRID.put(24877, "PSAD56 / UTM zone 17S");
		SRID.put(24878, "PSAD56 / UTM zone 18S");
		SRID.put(24879, "PSAD56 / UTM zone 19S");
		SRID.put(24880, "PSAD56 / UTM zone 20S");
		SRID.put(24891, "PSAD56 / Peru west zone");
		SRID.put(24892, "PSAD56 / Peru central zone");
		SRID.put(24893, "PSAD56 / Peru east zone");
		SRID.put(25000, "Leigon / Ghana Metre Grid");
		SRID.put(25231, "Lome / UTM zone 31N");
		SRID.put(25391, "Luzon 1911 / Philippines zone I");
		SRID.put(25392, "Luzon 1911 / Philippines zone II");
		SRID.put(25393, "Luzon 1911 / Philippines zone III");
		SRID.put(25394, "Luzon 1911 / Philippines zone IV");
		SRID.put(25395, "Luzon 1911 / Philippines zone V");
		SRID.put(2550, "Samboja / UTM zone 50S");
		SRID.put(25828, "ETRS89 / UTM zone 28N");
		SRID.put(25829, "ETRS89 / UTM zone 29N");
		SRID.put(25830, "ETRS89 / UTM zone 30N");
		SRID.put(25831, "ETRS89 / UTM zone 31N");
		SRID.put(25832, "ETRS89 / UTM zone 32N");
		SRID.put(25833, "ETRS89 / UTM zone 33N");
		SRID.put(25834, "ETRS89 / UTM zone 34N");
		SRID.put(25835, "ETRS89 / UTM zone 35N");
		SRID.put(25836, "ETRS89 / UTM zone 36N");
		SRID.put(25837, "ETRS89 / UTM zone 37N");
		SRID.put(25838, "ETRS89 / UTM zone 38N");
		SRID.put(25932, "Malongo 1987 / UTM zone 32S");
		SRID.put(2600, "Lietuvos Koordinoei Sistema 1994");
		SRID.put(26237, "Massawa / UTM zone 37N");
		SRID.put(26331, "Minna / UTM zone 31N");
		SRID.put(26332, "Minna / UTM zone 32N");
		SRID.put(26391, "Minna / Nigeria West Belt");
		SRID.put(26392, "Minna / Nigeria Mid Belt");
		SRID.put(26393, "Minna / Nigeria East Belt");
		SRID.put(26432, "Mhast / UTM zone 32S");
		SRID.put(26591, "Monte Mario (Rome) / Italy zone 1");
		SRID.put(26592, "Monte Mario (Rome) / Italy zone 2");
		SRID.put(26632, "M'poraloko / UTM zone 32N");
		SRID.put(26692, "M'poraloko / UTM zone 32S");
		SRID.put(26703, "NAD27 / UTM zone 3N");
		SRID.put(26704, "NAD27 / UTM zone 4N");
		SRID.put(26705, "NAD27 / UTM zone 5N");
		SRID.put(26706, "NAD27 / UTM zone 6N");
		SRID.put(26707, "NAD27 / UTM zone 7N");
		SRID.put(26708, "NAD27 / UTM zone 8N");
		SRID.put(26709, "NAD27 / UTM zone 9N");
		SRID.put(26710, "NAD27 / UTM zone 10N");
		SRID.put(26711, "NAD27 / UTM zone 11N");
		SRID.put(26712, "NAD27 / UTM zone 12N");
		SRID.put(26713, "NAD27 / UTM zone 13N");
		SRID.put(26714, "NAD27 / UTM zone 14N");
		SRID.put(26715, "NAD27 / UTM zone 15N");
		SRID.put(26716, "NAD27 / UTM zone 16N");
		SRID.put(26717, "NAD27 / UTM zone 17N");
		SRID.put(26718, "NAD27 / UTM zone 18N");
		SRID.put(26719, "NAD27 / UTM zone 19N");
		SRID.put(26720, "NAD27 / UTM zone 20N");
		SRID.put(26721, "NAD27 / UTM zone 21N");
		SRID.put(26722, "NAD27 / UTM zone 22N");
		SRID.put(26729, "NAD27 / Alabama East");
		SRID.put(26730, "NAD27 / Alabama West");
		SRID.put(26732, "NAD27 / Alaska zone 2");
		SRID.put(26733, "NAD27 / Alaska zone 3");
		SRID.put(26734, "NAD27 / Alaska zone 4");
		SRID.put(26735, "NAD27 / Alaska zone 5");
		SRID.put(26736, "NAD27 / Alaska zone 6");
		SRID.put(26737, "NAD27 / Alaska zone 7");
		SRID.put(26738, "NAD27 / Alaska zone 8");
		SRID.put(26739, "NAD27 / Alaska zone 9");
		SRID.put(26740, "NAD27 / Alaska zone 10");
		SRID.put(26741, "NAD27 / California zone I");
		SRID.put(26742, "NAD27 / California zone II");
		SRID.put(26743, "NAD27 / California zone III");
		SRID.put(26744, "NAD27 / California zone IV");
		SRID.put(26745, "NAD27 / California zone V");
		SRID.put(26746, "NAD27 / California zone VI");
		SRID.put(26747, "NAD27 / California zone VII");
		SRID.put(26748, "NAD27 / Arizona East");
		SRID.put(26749, "NAD27 / Arizona Central");
		SRID.put(26750, "NAD27 / Arizona West");
		SRID.put(26751, "NAD27 / Arkansas North");
		SRID.put(26752, "NAD27 / Arkansas South");
		SRID.put(26753, "NAD27 / Colorado North");
		SRID.put(26754, "NAD27 / Colorado Central");
		SRID.put(26755, "NAD27 / Colorado South");
		SRID.put(26756, "NAD27 / Connecticut");
		SRID.put(26757, "NAD27 / Delaware");
		SRID.put(26758, "NAD27 / Florida East");
		SRID.put(26759, "NAD27 / Florida West");
		SRID.put(26760, "NAD27 / Florida North");
		SRID.put(26761, "NAD27 / Hawaii zone 1");
		SRID.put(26762, "NAD27 / Hawaii zone 2");
		SRID.put(26763, "NAD27 / Hawaii zone 3");
		SRID.put(26764, "NAD27 / Hawaii zone 4");
		SRID.put(26765, "NAD27 / Hawaii zone 5");
		SRID.put(26766, "NAD27 / Georgia East");
		SRID.put(26767, "NAD27 / Georgia West");
		SRID.put(26768, "NAD27 / Idaho East");
		SRID.put(26769, "NAD27 / Idaho Central");
		SRID.put(26770, "NAD27 / Idaho West");
		SRID.put(26771, "NAD27 / Illinois East");
		SRID.put(26772, "NAD27 / Illinois West");
		SRID.put(26773, "NAD27 / Indiana East");
		SRID.put(26774, "NAD27 / Indiana West");
		SRID.put(26775, "NAD27 / Iowa North");
		SRID.put(26776, "NAD27 / Iowa South");
		SRID.put(26777, "NAD27 / Kansas North");
		SRID.put(26778, "NAD27 / Kansas South");
		SRID.put(26779, "NAD27 / Kentucky North");
		SRID.put(26780, "NAD27 / Kentucky South");
		SRID.put(26781, "NAD27 / Louisiana North");
		SRID.put(26782, "NAD27 / Louisiana South");
		SRID.put(26783, "NAD27 / Maine East");
		SRID.put(26784, "NAD27 / Maine West");
		SRID.put(26785, "NAD27 / Maryland");
		SRID.put(26786, "NAD27 / Massachusetts Mainland");
		SRID.put(26787, "NAD27 / Massachusetts Island");
		SRID.put(26791, "NAD27 / Minnesota North");
		SRID.put(26792, "NAD27 / Minnesota Central");
		SRID.put(26793, "NAD27 / Minnesota South");
		SRID.put(26794, "NAD27 / Mississippi East");
		SRID.put(26795, "NAD27 / Mississippi West");
		SRID.put(26796, "NAD27 / Missouri East");
		SRID.put(26797, "NAD27 / Missouri Central");
		SRID.put(26798, "NAD27 / Missouri West");
		SRID.put(26801, "NAD Michigan / Michigan East");
		SRID.put(26802, "NAD Michigan / Michigan Old Central");
		SRID.put(26803, "NAD Michigan / Michigan West");
		SRID.put(26811, "NAD Michigan / Michigan North");
		SRID.put(26812, "NAD Michigan / Michigan Central");
		SRID.put(26813, "NAD Michigan / Michigan South");
		SRID.put(26903, "NAD83 / UTM zone 3N");
		SRID.put(26904, "NAD83 / UTM zone 4N");
		SRID.put(26905, "NAD83 / UTM zone 5N");
		SRID.put(26906, "NAD83 / UTM zone 6N");
		SRID.put(26907, "NAD83 / UTM zone 7N");
		SRID.put(26908, "NAD83 / UTM zone 8N");
		SRID.put(26909, "NAD83 / UTM zone 9N");
		SRID.put(26910, "NAD83 / UTM zone 10N");
		SRID.put(26911, "NAD83 / UTM zone 11N");
		SRID.put(26912, "NAD83 / UTM zone 12N");
		SRID.put(26913, "NAD83 / UTM zone 13N");
		SRID.put(26914, "NAD83 / UTM zone 14N");
		SRID.put(26915, "NAD83 / UTM zone 15N");
		SRID.put(26916, "NAD83 / UTM zone 16N");
		SRID.put(26917, "NAD83 / UTM zone 17N");
		SRID.put(26918, "NAD83 / UTM zone 18N");
		SRID.put(26919, "NAD83 / UTM zone 19N");
		SRID.put(26920, "NAD83 / UTM zone 20N");
		SRID.put(26921, "NAD83 / UTM zone 21N");
		SRID.put(26922, "NAD83 / UTM zone 22N");
		SRID.put(26923, "NAD83 / UTM zone 23N");
		SRID.put(26929, "NAD83 / Alabama East");
		SRID.put(26930, "NAD83 / Alabama West");
		SRID.put(26932, "NAD83 / Alaska zone 2");
		SRID.put(26933, "NAD83 / Alaska zone 3");
		SRID.put(26934, "NAD83 / Alaska zone 4");
		SRID.put(26935, "NAD83 / Alaska zone 5");
		SRID.put(26936, "NAD83 / Alaska zone 6");
		SRID.put(26937, "NAD83 / Alaska zone 7");
		SRID.put(26938, "NAD83 / Alaska zone 8");
		SRID.put(26939, "NAD83 / Alaska zone 9");
		SRID.put(26940, "NAD83 / Alaska zone 10");
		SRID.put(26941, "NAD83 / California zone 1");
		SRID.put(26942, "NAD83 / California zone 2");
		SRID.put(26943, "NAD83 / California zone 3");
		SRID.put(26944, "NAD83 / California zone 4");
		SRID.put(26945, "NAD83 / California zone 5");
		SRID.put(26946, "NAD83 / California zone 6");
		SRID.put(26948, "NAD83 / Arizona East");
		SRID.put(26949, "NAD83 / Arizona Central");
		SRID.put(26950, "NAD83 / Arizona West");
		SRID.put(26951, "NAD83 / Arkansas North");
		SRID.put(26952, "NAD83 / Arkansas South");
		SRID.put(26953, "NAD83 / Colorado North");
		SRID.put(26954, "NAD83 / Colorado Central");
		SRID.put(26955, "NAD83 / Colorado South");
		SRID.put(26956, "NAD83 / Connecticut");
		SRID.put(26957, "NAD83 / Delaware");
		SRID.put(26958, "NAD83 / Florida East");
		SRID.put(26959, "NAD83 / Florida West");
		SRID.put(26960, "NAD83 / Florida North");
		SRID.put(26961, "NAD83 / Hawaii zone 1");
		SRID.put(26962, "NAD83 / Hawaii zone 2");
		SRID.put(26963, "NAD83 / Hawaii zone 3");
		SRID.put(26964, "NAD83 / Hawaii zone 4");
		SRID.put(26965, "NAD83 / Hawaii zone 5");
		SRID.put(26966, "NAD83 / Georgia East");
		SRID.put(26967, "NAD83 / Georgia West");
		SRID.put(26968, "NAD83 / Idaho East");
		SRID.put(26969, "NAD83 / Idaho Central");
		SRID.put(26970, "NAD83 / Idaho West");
		SRID.put(26971, "NAD83 / Illinois East");
		SRID.put(26972, "NAD83 / Illinois West");
		SRID.put(26973, "NAD83 / Indiana East");
		SRID.put(26974, "NAD83 / Indiana West");
		SRID.put(26975, "NAD83 / Iowa North");
		SRID.put(26976, "NAD83 / Iowa South");
		SRID.put(26977, "NAD83 / Kansas North");
		SRID.put(26978, "NAD83 / Kansas South");
		SRID.put(26979, "NAD83 / Kentucky North");
		SRID.put(26980, "NAD83 / Kentucky South");
		SRID.put(26981, "NAD83 / Louisiana North");
		SRID.put(26982, "NAD83 / Louisiana South");
		SRID.put(26983, "NAD83 / Maine East");
		SRID.put(26984, "NAD83 / Maine West");
		SRID.put(26985, "NAD83 / Maryland");
		SRID.put(26986, "NAD83 / Massachusetts Mainland");
		SRID.put(26987, "NAD83 / Massachusetts Island");
		SRID.put(26988, "NAD83 / Michigan North");
		SRID.put(26989, "NAD83 / Michigan Central");
		SRID.put(26990, "NAD83 / Michigan South");
		SRID.put(26991, "NAD83 / Minnesota North");
		SRID.put(26992, "NAD83 / Minnesota Central");
		SRID.put(26993, "NAD83 / Minnesota South");
		SRID.put(26994, "NAD83 / Mississippi East");
		SRID.put(26995, "NAD83 / Mississippi West");
		SRID.put(26996, "NAD83 / Missouri East");
		SRID.put(26997, "NAD83 / Missouri Central");
		SRID.put(26998, "NAD83 / Missouri West");
		SRID.put(27038, "Nahrwan 1967 / UTM zone 38N");
		SRID.put(27039, "Nahrwan 1967 / UTM zone 39N");
		SRID.put(27040, "Nahrwan 1967 / UTM zone 40N");
		SRID.put(27120, "Naparima 1972 / UTM zone 20N");
		SRID.put(27291, "GD49 / North Island Grid");
		SRID.put(27292, "GD49 / South Island Grid");
		SRID.put(2736, "Tete / UTM zone 36S");
		SRID.put(2737, "Tete / UTM zone 37S");
		SRID.put(27429, "Datum 73 / UTM zone 29N");
		SRID.put(27581, "NTF(Paris)/Lambert I");
		SRID.put(27582, "NTF(Paris)/Lambert II (étendu)");
		SRID.put(27583, "NTF(Paris)/Lambert III");
		SRID.put(27584, "NTF(Paris)/Lambert IV");
		SRID.put(27591, "NTF(Paris)/Nord France(Lambert I carto)");
		SRID.put(27592, "NTF(Paris)/Centre France(Lambert II carto)");
		SRID.put(27593, "NTF(Paris)/Sud France(Lambert III carto)");
		SRID.put(27594, "NTF(Paris)/Corse (Lambert IV carto)");
		SRID.put(27700, "OSGB 1936 / British National Grid");
		SRID.put(28232, "Pointe Noire / UTM zone 32S");
		SRID.put(28348, "GDA94 / MGA zone 48");
		SRID.put(28349, "GDA94 / MGA zone 49");
		SRID.put(28350, "GDA94 / MGA zone 50");
		SRID.put(28351, "GDA94 / MGA zone 51");
		SRID.put(28352, "GDA94 / MGA zone 52");
		SRID.put(28353, "GDA94 / MGA zone 53");
		SRID.put(28354, "GDA94 / MGA zone 54");
		SRID.put(28355, "GDA94 / MGA zone 55");
		SRID.put(28356, "GDA94 / MGA zone 56");
		SRID.put(28357, "GDA94 / MGA zone 57");
		SRID.put(28358, "GDA94 / MGA zone 58");
		SRID.put(28402, "Pulkovo 1942 / Gauss-Kruger zone 2");
		SRID.put(28403, "Pulkovo 1942 / Gauss-Kruger zone 3");
		SRID.put(28404, "Pulkovo 1942 / Gauss-Kruger zone 4");
		SRID.put(28405, "Pulkovo 1942 / Gauss-Kruger zone 5");
		SRID.put(28406, "Pulkovo 1942 / Gauss-Kruger zone 6");
		SRID.put(28407, "Pulkovo 1942 / Gauss-Kruger zone 7");
		SRID.put(28408, "Pulkovo 1942 / Gauss-Kruger zone 8");
		SRID.put(28409, "Pulkovo 1942 / Gauss-Kruger zone 9");
		SRID.put(28410, "Pulkovo 1942 / Gauss-Kruger zone 10");
		SRID.put(28411, "Pulkovo 1942 / Gauss-Kruger zone 11");
		SRID.put(28412, "Pulkovo 1942 / Gauss-Kruger zone 12");
		SRID.put(28413, "Pulkovo 1942 / Gauss-Kruger zone 13");
		SRID.put(28414, "Pulkovo 1942 / Gauss-Kruger zone 14");
		SRID.put(28415, "Pulkovo 1942 / Gauss-Kruger zone 15");
		SRID.put(28416, "Pulkovo 1942 / Gauss-Kruger zone 16");
		SRID.put(28417, "Pulkovo 1942 / Gauss-Kruger zone 17");
		SRID.put(28418, "Pulkovo 1942 / Gauss-Kruger zone 18");
		SRID.put(28419, "Pulkovo 1942 / Gauss-Kruger zone 19");
		SRID.put(28420, "Pulkovo 1942 / Gauss-Kruger zone 20");
		SRID.put(28421, "Pulkovo 1942 / Gauss-Kruger zone 21");
		SRID.put(28422, "Pulkovo 1942 / Gauss-Kruger zone 22");
		SRID.put(28423, "Pulkovo 1942 / Gauss-Kruger zone 23");
		SRID.put(28424, "Pulkovo 1942 / Gauss-Kruger zone 24");
		SRID.put(28425, "Pulkovo 1942 / Gauss-Kruger zone 25");
		SRID.put(28426, "Pulkovo 1942 / Gauss-Kruger zone 26");
		SRID.put(28427, "Pulkovo 1942 / Gauss-Kruger zone 27");
		SRID.put(28428, "Pulkovo 1942 / Gauss-Kruger zone 28");
		SRID.put(28429, "Pulkovo 1942 / Gauss-Kruger zone 29");
		SRID.put(28430, "Pulkovo 1942 / Gauss-Kruger zone 30");
		SRID.put(28431, "Pulkovo 1942 / Gauss-Kruger zone 31");
		SRID.put(28432, "Pulkovo 1942 / Gauss-Kruger zone 32");
		SRID.put(28462, "Pulkovo 1942 / Gauss-Kruger 2N");
		SRID.put(28463, "Pulkovo 1942 / Gauss-Kruger 3N");
		SRID.put(28464, "Pulkovo 1942 / Gauss-Kruger 4N");
		SRID.put(28465, "Pulkovo 1942 / Gauss-Kruger 5N");
		SRID.put(28466, "Pulkovo 1942 / Gauss-Kruger 6N");
		SRID.put(28467, "Pulkovo 1942 / Gauss-Kruger 7N");
		SRID.put(28468, "Pulkovo 1942 / Gauss-Kruger 8N");
		SRID.put(28469, "Pulkovo 1942 / Gauss-Kruger 9N");
		SRID.put(28470, "Pulkovo 1942 / Gauss-Kruger 10N");
		SRID.put(28471, "Pulkovo 1942 / Gauss-Kruger 11N");
		SRID.put(28472, "Pulkovo 1942 / Gauss-Kruger 12N");
		SRID.put(28473, "Pulkovo 1942 / Gauss-Kruger 13N");
		SRID.put(28474, "Pulkovo 1942 / Gauss-Kruger 14N");
		SRID.put(28475, "Pulkovo 1942 / Gauss-Kruger 15N");
		SRID.put(28476, "Pulkovo 1942 / Gauss-Kruger 16N");
		SRID.put(28477, "Pulkovo 1942 / Gauss-Kruger 17N");
		SRID.put(28478, "Pulkovo 1942 / Gauss-Kruger 18N");
		SRID.put(28479, "Pulkovo 1942 / Gauss-Kruger 19N");
		SRID.put(28480, "Pulkovo 1942 / Gauss-Kruger 20N");
		SRID.put(28481, "Pulkovo 1942 / Gauss-Kruger 21N");
		SRID.put(28482, "Pulkovo 1942 / Gauss-Kruger 22N");
		SRID.put(28483, "Pulkovo 1942 / Gauss-Kruger 23N");
		SRID.put(28484, "Pulkovo 1942 / Gauss-Kruger 24N");
		SRID.put(28485, "Pulkovo 1942 / Gauss-Kruger 25N");
		SRID.put(28486, "Pulkovo 1942 / Gauss-Kruger 26N");
		SRID.put(28487, "Pulkovo 1942 / Gauss-Kruger 27N");
		SRID.put(28488, "Pulkovo 1942 / Gauss-Kruger 28N");
		SRID.put(28489, "Pulkovo 1942 / Gauss-Kruger 29N");
		SRID.put(28490, "Pulkovo 1942 / Gauss-Kruger 30N");
		SRID.put(28491, "Pulkovo 1942 / Gauss-Kruger 31N");
		SRID.put(28492, "Pulkovo 1942 / Gauss-Kruger 32N");
		SRID.put(28600, "Qatar / Qatar National Grid");
		SRID.put(29118, "SAD69 / UTM zone 18N");
		SRID.put(29119, "SAD69 / UTM zone 19N");
		SRID.put(29120, "SAD69 / UTM zone 20N");
		SRID.put(29121, "SAD69 / UTM zone 21N");
		SRID.put(29122, "SAD69 / UTM zone 22N");
		SRID.put(29177, "SAD69 / UTM zone 17S");
		SRID.put(29178, "SAD69 / UTM zone 18S");
		SRID.put(29179, "SAD69 / UTM zone 19S");
		SRID.put(29180, "SAD69 / UTM zone 20S");
		SRID.put(29181, "SAD69 / UTM zone 21S");
		SRID.put(29182, "SAD69 / UTM zone 22S");
		SRID.put(29183, "SAD69 / UTM zone 23S");
		SRID.put(29184, "SAD69 / UTM zone 24S");
		SRID.put(29185, "SAD69 / UTM zone 25S");
		SRID.put(29220, "Sapper Hill 1943 / UTM zone 20S");
		SRID.put(29221, "Sapper Hill 1943 / UTM zone 21S");
		SRID.put(29333, "Schwarzeck / UTM zone 33S");
		SRID.put(29635, "Sudan / UTM zone 35N");
		SRID.put(29636, "Sudan / UTM zone 36N");
		SRID.put(29738, "Tananarive / UTM zone 38S");
		SRID.put(29739, "Tananarive / UTM zone 39S");
		SRID.put(29849, "Timbalai 1948 / UTM zone 49N");
		SRID.put(29850, "Timbalai 1948 / UTM zone 50N");
		SRID.put(29900, "TM65 / Irish National Grid");
		SRID.put(30339, "TC(1948) / UTM zone 39N");
		SRID.put(30340, "TC(1948) / UTM zone 40N");
		SRID.put(3036, "Moznet / UTM zone 36S");
		SRID.put(3037, "Moznet / UTM zone 37S");
		SRID.put(30729, "Nord Sahara 1959 / UTM zone 29N");
		SRID.put(30730, "Nord Sahara 1959 / UTM zone 30N");
		SRID.put(30731, "Nord Sahara 1959 / UTM zone 31N");
		SRID.put(30732, "Nord Sahara 1959 / UTM zone 32N");
		SRID.put(30800, "RT38 2.5 gon W");
		SRID.put(31028, "Yoff / UTM zone 28N");
		SRID.put(31121, "Zanderij / UTM zone 21N");
		SRID.put(31291, "MGI (Ferro) / Austria West Zone");
		SRID.put(31292, "MGI (Ferro) / Austria Central Zone");
		SRID.put(31293, "MGI (Ferro) / Austria East Zone");
		SRID.put(3148, "Indian 1960 / UTM zone 48N");
		SRID.put(3149, "Indian 1960 / UTM zone 49N");
		SRID.put(31491, "DHDN / Germany zone 1");
		SRID.put(31492, "DHDN / Germany zone 2");
		SRID.put(31493, "DHDN / Germany zone 3");
		SRID.put(31494, "DHDN / Germany zone 4");
		SRID.put(31495, "DHDN / Germany zone 5");
		SRID.put(3176, "Indian 1960 / TM 106 NE");
		SRID.put(31838, "NGN / UTM zone 38N");
		SRID.put(31839, "NGN / UTM zone 39N");
		SRID.put(31900, "KUDAMS / KTM");
		SRID.put(32001, "NAD27 / Montana North");
		SRID.put(32002, "NAD27 / Montana Central");
		SRID.put(32003, "NAD27 / Montana South");
		SRID.put(32005, "NAD27 / Nebraska North");
		SRID.put(32006, "NAD27 / Nebraska South");
		SRID.put(32007, "NAD27 / Nevada East");
		SRID.put(32008, "NAD27 / Nevada Central");
		SRID.put(32009, "NAD27 / Nevada West");
		SRID.put(32010, "NAD27 / New Hampshire");
		SRID.put(32011, "NAD27 / New Jersey");
		SRID.put(32012, "NAD27 / New Mexico East");
		SRID.put(32013, "NAD27 / New Mexico Central");
		SRID.put(32014, "NAD27 / New Mexico West");
		SRID.put(32015, "NAD27 / New York East");
		SRID.put(32016, "NAD27 / New York Central");
		SRID.put(32017, "NAD27 / New York West");
		SRID.put(32018, "NAD27 / New York Long Island");
		SRID.put(32019, "NAD27 / North Carolina");
		SRID.put(32020, "NAD27 / North Dakota North");
		SRID.put(32021, "NAD27 / North Dakota South");
		SRID.put(32022, "NAD27 / Ohio North");
		SRID.put(32023, "NAD27 / Ohio South");
		SRID.put(32024, "NAD27 / Oklahoma North");
		SRID.put(32025, "NAD27 / Oklahoma South");
		SRID.put(32026, "NAD27 / Oregon North");
		SRID.put(32027, "NAD27 / Oregon South");
		SRID.put(32028, "NAD27 / Pennsylvania North");
		SRID.put(32029, "NAD27 / Pennsylvania South");
		SRID.put(32030, "NAD27 / Rhode Island");
		SRID.put(32031, "NAD27 / South Carolina North");
		SRID.put(32033, "NAD27 / South Carolina South");
		SRID.put(32034, "NAD27 / South Dakota North");
		SRID.put(32035, "NAD27 / South Dakota South");
		SRID.put(32036, "NAD27 / Tennessee");
		SRID.put(32037, "NAD27 / Texas North");
		SRID.put(32038, "NAD27 / Texas North Central");
		SRID.put(32039, "NAD27 / Texas Central");
		SRID.put(32040, "NAD27 / Texas South Central");
		SRID.put(32041, "NAD27 / Texas South");
		SRID.put(32042, "NAD27 / Utah North");
		SRID.put(32043, "NAD27 / Utah Central");
		SRID.put(32044, "NAD27 / Utah South");
		SRID.put(32045, "NAD27 / Vermont");
		SRID.put(32046, "NAD27 / Virginia North");
		SRID.put(32047, "NAD27 / Virginia South");
		SRID.put(32048, "NAD27 / Washington North");
		SRID.put(32049, "NAD27 / Washington South");
		SRID.put(32050, "NAD27 / West Virginia North");
		SRID.put(32051, "NAD27 / West Virginia South");
		SRID.put(32052, "NAD27 / Wisconsin North");
		SRID.put(32053, "NAD27 / Wisconsin Central");
		SRID.put(32054, "NAD27 / Wisconsin South");
		SRID.put(32055, "NAD27 / Wyoming East");
		SRID.put(32056, "NAD27 / Wyoming East Central");
		SRID.put(32057, "NAD27 / Wyoming West Central");
		SRID.put(32058, "NAD27 / Wyoming West");
		SRID.put(32059, "NAD27 / Puerto Rico");
		SRID.put(32060, "NAD27 / St. Croix");
		SRID.put(32074, "NAD27 / BLM 14N (feet)");
		SRID.put(32075, "NAD27 / BLM 15N (feet)");
		SRID.put(32076, "NAD27 / BLM 16N (feet)");
		SRID.put(32077, "NAD27 / BLM 17N (feet)");
		SRID.put(32080, "NAD27 / SCoPQ zone 2");
		SRID.put(32081, "NAD27 / MTM zone 1");
		SRID.put(32082, "NAD27 / MTM zone 2");
		SRID.put(32083, "NAD27 / MTM zone 3");
		SRID.put(32084, "NAD27 / MTM zone 4");
		SRID.put(32085, "NAD27 / MTM zone 5");
		SRID.put(32086, "NAD27 / MTM zone 6");
		SRID.put(32087, "NAD27 / MTM zone 7");
		SRID.put(32088, "NAD27 / MTM zone 8");
		SRID.put(32089, "NAD27 / MTM zone 9");
		SRID.put(32090, "NAD27 / MTM zone 10");
		SRID.put(32091, "NAD27 / MTM zone 11");
		SRID.put(32092, "NAD27 / MTM zone 12");
		SRID.put(32093, "NAD27 / MTM zone 13");
		SRID.put(32094, "NAD27 / MTM zone 14");
		SRID.put(32095, "NAD27 / MTM zone 15");
		SRID.put(32096, "NAD27 / MTM zone 16");
		SRID.put(32097, "NAD27 / MTM zone 17");
		SRID.put(32100, "NAD83 / Montana");
		SRID.put(32104, "NAD83 / Nebraska");
		SRID.put(32107, "NAD83 / Nevada East");
		SRID.put(32108, "NAD83 / Nevada Central");
		SRID.put(32109, "NAD83 / Nevada West");
		SRID.put(32110, "NAD83 / New Hampshire");
		SRID.put(32111, "NAD83 / New Jersey");
		SRID.put(32112, "NAD83 / New Mexico East");
		SRID.put(32113, "NAD83 / New Mexico Central");
		SRID.put(32114, "NAD83 / New Mexico West");
		SRID.put(32115, "NAD83 / New York East");
		SRID.put(32116, "NAD83 / New York Central");
		SRID.put(32117, "NAD83 / New York West");
		SRID.put(32118, "NAD83 / New York Long Island");
		SRID.put(32119, "NAD83 / North Carolina");
		SRID.put(32120, "NAD83 / North Dakota North");
		SRID.put(32121, "NAD83 / North Dakota South");
		SRID.put(32122, "NAD83 / Ohio North");
		SRID.put(32123, "NAD83 / Ohio South");
		SRID.put(32124, "NAD83 / Oklahoma North");
		SRID.put(32125, "NAD83 / Oklahoma South");
		SRID.put(32126, "NAD83 / Oregon North");
		SRID.put(32127, "NAD83 / Oregon South");
		SRID.put(32128, "NAD83 / Pennsylvania North");
		SRID.put(32129, "NAD83 / Pennsylvania South");
		SRID.put(32130, "NAD83 / Rhode Island");
		SRID.put(32133, "NAD83 / South Carolina");
		SRID.put(32134, "NAD83 / South Dakota North");
		SRID.put(32135, "NAD83 / South Dakota South");
		SRID.put(32136, "NAD83 / Tennessee");
		SRID.put(32137, "NAD83 / Texas North");
		SRID.put(32138, "NAD83 / Texas North Central");
		SRID.put(32139, "NAD83 / Texas Central");
		SRID.put(32140, "NAD83 / Texas South Central");
		SRID.put(32141, "NAD83 / Texas South");
		SRID.put(32142, "NAD83 / Utah North");
		SRID.put(32143, "NAD83 / Utah Central");
		SRID.put(32144, "NAD83 / Utah South");
		SRID.put(32145, "NAD83 / Vermont");
		SRID.put(32146, "NAD83 / Virginia North");
		SRID.put(32147, "NAD83 / Virginia South");
		SRID.put(32148, "NAD83 / Washington North");
		SRID.put(32149, "NAD83 / Washington South");
		SRID.put(32150, "NAD83 / West Virginia North");
		SRID.put(32151, "NAD83 / West Virginia South");
		SRID.put(32152, "NAD83 / Wisconsin North");
		SRID.put(32153, "NAD83 / Wisconsin Central");
		SRID.put(32154, "NAD83 / Wisconsin South");
		SRID.put(32155, "NAD83 / Wyoming East");
		SRID.put(32156, "NAD83 / Wyoming East Central");
		SRID.put(32157, "NAD83 / Wyoming West Central");
		SRID.put(32158, "NAD83 / Wyoming West");
		SRID.put(32161, "NAD83 / Puerto Rico & Virgin Is.");
		SRID.put(32180, "NAD83 / SCoPQ zone 2");
		SRID.put(32181, "NAD83 / MTM zone 1");
		SRID.put(32182, "NAD83 / MTM zone 2");
		SRID.put(32183, "NAD83 / MTM zone 3");
		SRID.put(32184, "NAD83 / MTM zone 4");
		SRID.put(32185, "NAD83 / MTM zone 5");
		SRID.put(32186, "NAD83 / MTM zone 6");
		SRID.put(32187, "NAD83 / MTM zone 7");
		SRID.put(32188, "NAD83 / MTM zone 8");
		SRID.put(32189, "NAD83 / MTM zone 9");
		SRID.put(32190, "NAD83 / MTM zone 10");
		SRID.put(32191, "NAD83 / MTM zone 11");
		SRID.put(32192, "NAD83 / MTM zone 12");
		SRID.put(32193, "NAD83 / MTM zone 13");
		SRID.put(32194, "NAD83 / MTM zone 14");
		SRID.put(32195, "NAD83 / MTM zone 15");
		SRID.put(32196, "NAD83 / MTM zone 16");
		SRID.put(32197, "NAD83 / MTM zone 17");
		SRID.put(32201, "WGS 72 / UTM zone 1N");
		SRID.put(32202, "WGS 72 / UTM zone 2N");
		SRID.put(32203, "WGS 72 / UTM zone 3N");
		SRID.put(32204, "WGS 72 / UTM zone 4N");
		SRID.put(32205, "WGS 72 / UTM zone 5N");
		SRID.put(32206, "WGS 72 / UTM zone 6N");
		SRID.put(32207, "WGS 72 / UTM zone 7N");
		SRID.put(32208, "WGS 72 / UTM zone 8N");
		SRID.put(32209, "WGS 72 / UTM zone 9N");
		SRID.put(32210, "WGS 72 / UTM zone 10N");
		SRID.put(32211, "WGS 72 / UTM zone 11N");
		SRID.put(32212, "WGS 72 / UTM zone 12N");
		SRID.put(32213, "WGS 72 / UTM zone 13N");
		SRID.put(32214, "WGS 72 / UTM zone 14N");
		SRID.put(32215, "WGS 72 / UTM zone 15N");
		SRID.put(32216, "WGS 72 / UTM zone 16N");
		SRID.put(32217, "WGS 72 / UTM zone 17N");
		SRID.put(32218, "WGS 72 / UTM zone 18N");
		SRID.put(32219, "WGS 72 / UTM zone 19N");
		SRID.put(32220, "WGS 72 / UTM zone 20N");
		SRID.put(32221, "WGS 72 / UTM zone 21N");
		SRID.put(32222, "WGS 72 / UTM zone 22N");
		SRID.put(32223, "WGS 72 / UTM zone 23N");
		SRID.put(32224, "WGS 72 / UTM zone 24N");
		SRID.put(32225, "WGS 72 / UTM zone 25N");
		SRID.put(32226, "WGS 72 / UTM zone 26N");
		SRID.put(32227, "WGS 72 / UTM zone 27N");
		SRID.put(32228, "WGS 72 / UTM zone 28N");
		SRID.put(32229, "WGS 72 / UTM zone 29N");
		SRID.put(32230, "WGS 72 / UTM zone 30N");
		SRID.put(32231, "WGS 72 / UTM zone 31N");
		SRID.put(32232, "WGS 72 / UTM zone 32N");
		SRID.put(32233, "WGS 72 / UTM zone 33N");
		SRID.put(32234, "WGS 72 / UTM zone 34N");
		SRID.put(32235, "WGS 72 / UTM zone 35N");
		SRID.put(32236, "WGS 72 / UTM zone 36N");
		SRID.put(32237, "WGS 72 / UTM zone 37N");
		SRID.put(32238, "WGS 72 / UTM zone 38N");
		SRID.put(32239, "WGS 72 / UTM zone 39N");
		SRID.put(32240, "WGS 72 / UTM zone 40N");
		SRID.put(32241, "WGS 72 / UTM zone 41N");
		SRID.put(32242, "WGS 72 / UTM zone 42N");
		SRID.put(32243, "WGS 72 / UTM zone 43N");
		SRID.put(32244, "WGS 72 / UTM zone 44N");
		SRID.put(32245, "WGS 72 / UTM zone 45N");
		SRID.put(32246, "WGS 72 / UTM zone 46N");
		SRID.put(32247, "WGS 72 / UTM zone 47N");
		SRID.put(32248, "WGS 72 / UTM zone 48N");
		SRID.put(32249, "WGS 72 / UTM zone 49N");
		SRID.put(32250, "WGS 72 / UTM zone 50N");
		SRID.put(32251, "WGS 72 / UTM zone 51N");
		SRID.put(32252, "WGS 72 / UTM zone 52N");
		SRID.put(32253, "WGS 72 / UTM zone 53N");
		SRID.put(32254, "WGS 72 / UTM zone 54N");
		SRID.put(32255, "WGS 72 / UTM zone 55N");
		SRID.put(32256, "WGS 72 / UTM zone 56N");
		SRID.put(32257, "WGS 72 / UTM zone 57N");
		SRID.put(32258, "WGS 72 / UTM zone 58N");
		SRID.put(32259, "WGS 72 / UTM zone 59N");
		SRID.put(32260, "WGS 72 / UTM zone 60N");
		SRID.put(32301, "WGS 72 / UTM zone 1S");
		SRID.put(32302, "WGS 72 / UTM zone 2S");
		SRID.put(32303, "WGS 72 / UTM zone 3S");
		SRID.put(32304, "WGS 72 / UTM zone 4S");
		SRID.put(32305, "WGS 72 / UTM zone 5S");
		SRID.put(32306, "WGS 72 / UTM zone 6S");
		SRID.put(32307, "WGS 72 / UTM zone 7S");
		SRID.put(32308, "WGS 72 / UTM zone 8S");
		SRID.put(32309, "WGS 72 / UTM zone 9S");
		SRID.put(32310, "WGS 72 / UTM zone 10S");
		SRID.put(32311, "WGS 72 / UTM zone 11S");
		SRID.put(32312, "WGS 72 / UTM zone 12S");
		SRID.put(32313, "WGS 72 / UTM zone 13S");
		SRID.put(32314, "WGS 72 / UTM zone 14S");
		SRID.put(32315, "WGS 72 / UTM zone 15S");
		SRID.put(32316, "WGS 72 / UTM zone 16S");
		SRID.put(32317, "WGS 72 / UTM zone 17S");
		SRID.put(32318, "WGS 72 / UTM zone 18S");
		SRID.put(32319, "WGS 72 / UTM zone 19S");
		SRID.put(32320, "WGS 72 / UTM zone 20S");
		SRID.put(32321, "WGS 72 / UTM zone 21S");
		SRID.put(32322, "WGS 72 / UTM zone 22S");
		SRID.put(32323, "WGS 72 / UTM zone 23S");
		SRID.put(32324, "WGS 72 / UTM zone 24S");
		SRID.put(32325, "WGS 72 / UTM zone 25S");
		SRID.put(32326, "WGS 72 / UTM zone 26S");
		SRID.put(32327, "WGS 72 / UTM zone 27S");
		SRID.put(32328, "WGS 72 / UTM zone 28S");
		SRID.put(32329, "WGS 72 / UTM zone 29S");
		SRID.put(32330, "WGS 72 / UTM zone 30S");
		SRID.put(32331, "WGS 72 / UTM zone 31S");
		SRID.put(32332, "WGS 72 / UTM zone 32S");
		SRID.put(32333, "WGS 72 / UTM zone 33S");
		SRID.put(32334, "WGS 72 / UTM zone 34S");
		SRID.put(32335, "WGS 72 / UTM zone 35S");
		SRID.put(32336, "WGS 72 / UTM zone 36S");
		SRID.put(32337, "WGS 72 / UTM zone 37S");
		SRID.put(32338, "WGS 72 / UTM zone 38S");
		SRID.put(32339, "WGS 72 / UTM zone 39S");
		SRID.put(32340, "WGS 72 / UTM zone 40S");
		SRID.put(32341, "WGS 72 / UTM zone 41S");
		SRID.put(32342, "WGS 72 / UTM zone 42S");
		SRID.put(32343, "WGS 72 / UTM zone 43S");
		SRID.put(32344, "WGS 72 / UTM zone 44S");
		SRID.put(32345, "WGS 72 / UTM zone 45S");
		SRID.put(32346, "WGS 72 / UTM zone 46S");
		SRID.put(32347, "WGS 72 / UTM zone 47S");
		SRID.put(32348, "WGS 72 / UTM zone 48S");
		SRID.put(32349, "WGS 72 / UTM zone 49S");
		SRID.put(32350, "WGS 72 / UTM zone 50S");
		SRID.put(32351, "WGS 72 / UTM zone 51S");
		SRID.put(32352, "WGS 72 / UTM zone 52S");
		SRID.put(32353, "WGS 72 / UTM zone 53S");
		SRID.put(32354, "WGS 72 / UTM zone 54S");
		SRID.put(32355, "WGS 72 / UTM zone 55S");
		SRID.put(32356, "WGS 72 / UTM zone 56S");
		SRID.put(32357, "WGS 72 / UTM zone 57S");
		SRID.put(32358, "WGS 72 / UTM zone 58S");
		SRID.put(32359, "WGS 72 / UTM zone 59S");
		SRID.put(32360, "WGS 72 / UTM zone 60S");
		SRID.put(32401, "WGS 72BE / UTM zone 1N");
		SRID.put(32402, "WGS 72BE / UTM zone 2N");
		SRID.put(32403, "WGS 72BE / UTM zone 3N");
		SRID.put(32404, "WGS 72BE / UTM zone 4N");
		SRID.put(32405, "WGS 72BE / UTM zone 5N");
		SRID.put(32406, "WGS 72BE / UTM zone 6N");
		SRID.put(32407, "WGS 72BE / UTM zone 7N");
		SRID.put(32408, "WGS 72BE / UTM zone 8N");
		SRID.put(32409, "WGS 72BE / UTM zone 9N");
		SRID.put(32410, "WGS 72BE / UTM zone 10N");
		SRID.put(32411, "WGS 72BE / UTM zone 11N");
		SRID.put(32412, "WGS 72BE / UTM zone 12N");
		SRID.put(32413, "WGS 72BE / UTM zone 13N");
		SRID.put(32414, "WGS 72BE / UTM zone 14N");
		SRID.put(32415, "WGS 72BE / UTM zone 15N");
		SRID.put(32416, "WGS 72BE / UTM zone 16N");
		SRID.put(32417, "WGS 72BE / UTM zone 17N");
		SRID.put(32418, "WGS 72BE / UTM zone 18N");
		SRID.put(32419, "WGS 72BE / UTM zone 19N");
		SRID.put(32420, "WGS 72BE / UTM zone 20N");
		SRID.put(32421, "WGS 72BE / UTM zone 21N");
		SRID.put(32422, "WGS 72BE / UTM zone 22N");
		SRID.put(32423, "WGS 72BE / UTM zone 23N");
		SRID.put(32424, "WGS 72BE / UTM zone 24N");
		SRID.put(32425, "WGS 72BE / UTM zone 25N");
		SRID.put(32426, "WGS 72BE / UTM zone 26N");
		SRID.put(32427, "WGS 72BE / UTM zone 27N");
		SRID.put(32428, "WGS 72BE / UTM zone 28N");
		SRID.put(32429, "WGS 72BE / UTM zone 29N");
		SRID.put(32430, "WGS 72BE / UTM zone 30N");
		SRID.put(32431, "WGS 72BE / UTM zone 31N");
		SRID.put(32432, "WGS 72BE / UTM zone 32N");
		SRID.put(32433, "WGS 72BE / UTM zone 33N");
		SRID.put(32434, "WGS 72BE / UTM zone 34N");
		SRID.put(32435, "WGS 72BE / UTM zone 35N");
		SRID.put(32436, "WGS 72BE / UTM zone 36N");
		SRID.put(32437, "WGS 72BE / UTM zone 37N");
		SRID.put(32438, "WGS 72BE / UTM zone 38N");
		SRID.put(32439, "WGS 72BE / UTM zone 39N");
		SRID.put(32440, "WGS 72BE / UTM zone 40N");
		SRID.put(32441, "WGS 72BE / UTM zone 41N");
		SRID.put(32442, "WGS 72BE / UTM zone 42N");
		SRID.put(32443, "WGS 72BE / UTM zone 43N");
		SRID.put(32444, "WGS 72BE / UTM zone 44N");
		SRID.put(32445, "WGS 72BE / UTM zone 45N");
		SRID.put(32446, "WGS 72BE / UTM zone 46N");
		SRID.put(32447, "WGS 72BE / UTM zone 47N");
		SRID.put(32448, "WGS 72BE / UTM zone 48N");
		SRID.put(32449, "WGS 72BE / UTM zone 49N");
		SRID.put(32450, "WGS 72BE / UTM zone 50N");
		SRID.put(32451, "WGS 72BE / UTM zone 51N");
		SRID.put(32452, "WGS 72BE / UTM zone 52N");
		SRID.put(32453, "WGS 72BE / UTM zone 53N");
		SRID.put(32454, "WGS 72BE / UTM zone 54N");
		SRID.put(32455, "WGS 72BE / UTM zone 55N");
		SRID.put(32456, "WGS 72BE / UTM zone 56N");
		SRID.put(32457, "WGS 72BE / UTM zone 57N");
		SRID.put(32458, "WGS 72BE / UTM zone 58N");
		SRID.put(32459, "WGS 72BE / UTM zone 59N");
		SRID.put(32460, "WGS 72BE / UTM zone 60N");
		SRID.put(32501, "WGS 72BE / UTM zone 1S");
		SRID.put(32502, "WGS 72BE / UTM zone 2S");
		SRID.put(32503, "WGS 72BE / UTM zone 3S");
		SRID.put(32504, "WGS 72BE / UTM zone 4S");
		SRID.put(32505, "WGS 72BE / UTM zone 5S");
		SRID.put(32506, "WGS 72BE / UTM zone 6S");
		SRID.put(32507, "WGS 72BE / UTM zone 7S");
		SRID.put(32508, "WGS 72BE / UTM zone 8S");
		SRID.put(32509, "WGS 72BE / UTM zone 9S");
		SRID.put(32510, "WGS 72BE / UTM zone 10S");
		SRID.put(32511, "WGS 72BE / UTM zone 11S");
		SRID.put(32512, "WGS 72BE / UTM zone 12S");
		SRID.put(32513, "WGS 72BE / UTM zone 13S");
		SRID.put(32514, "WGS 72BE / UTM zone 14S");
		SRID.put(32515, "WGS 72BE / UTM zone 15S");
		SRID.put(32516, "WGS 72BE / UTM zone 16S");
		SRID.put(32517, "WGS 72BE / UTM zone 17S");
		SRID.put(32518, "WGS 72BE / UTM zone 18S");
		SRID.put(32519, "WGS 72BE / UTM zone 19S");
		SRID.put(32520, "WGS 72BE / UTM zone 20S");
		SRID.put(32521, "WGS 72BE / UTM zone 21S");
		SRID.put(32522, "WGS 72BE / UTM zone 22S");
		SRID.put(32523, "WGS 72BE / UTM zone 23S");
		SRID.put(32524, "WGS 72BE / UTM zone 24S");
		SRID.put(32525, "WGS 72BE / UTM zone 25S");
		SRID.put(32526, "WGS 72BE / UTM zone 26S");
		SRID.put(32527, "WGS 72BE / UTM zone 27S");
		SRID.put(32528, "WGS 72BE / UTM zone 28S");
		SRID.put(32529, "WGS 72BE / UTM zone 29S");
		SRID.put(32530, "WGS 72BE / UTM zone 30S");
		SRID.put(32531, "WGS 72BE / UTM zone 31S");
		SRID.put(32532, "WGS 72BE / UTM zone 32S");
		SRID.put(32533, "WGS 72BE / UTM zone 33S");
		SRID.put(32534, "WGS 72BE / UTM zone 34S");
		SRID.put(32535, "WGS 72BE / UTM zone 35S");
		SRID.put(32536, "WGS 72BE / UTM zone 36S");
		SRID.put(32537, "WGS 72BE / UTM zone 37S");
		SRID.put(32538, "WGS 72BE / UTM zone 38S");
		SRID.put(32539, "WGS 72BE / UTM zone 39S");
		SRID.put(32540, "WGS 72BE / UTM zone 40S");
		SRID.put(32541, "WGS 72BE / UTM zone 41S");
		SRID.put(32542, "WGS 72BE / UTM zone 42S");
		SRID.put(32543, "WGS 72BE / UTM zone 43S");
		SRID.put(32544, "WGS 72BE / UTM zone 44S");
		SRID.put(32545, "WGS 72BE / UTM zone 45S");
		SRID.put(32546, "WGS 72BE / UTM zone 46S");
		SRID.put(32547, "WGS 72BE / UTM zone 47S");
		SRID.put(32548, "WGS 72BE / UTM zone 48S");
		SRID.put(32549, "WGS 72BE / UTM zone 49S");
		SRID.put(32550, "WGS 72BE / UTM zone 50S");
		SRID.put(32551, "WGS 72BE / UTM zone 51S");
		SRID.put(32552, "WGS 72BE / UTM zone 52S");
		SRID.put(32553, "WGS 72BE / UTM zone 53S");
		SRID.put(32554, "WGS 72BE / UTM zone 54S");
		SRID.put(32555, "WGS 72BE / UTM zone 55S");
		SRID.put(32556, "WGS 72BE / UTM zone 56S");
		SRID.put(32557, "WGS 72BE / UTM zone 57S");
		SRID.put(32558, "WGS 72BE / UTM zone 58S");
		SRID.put(32559, "WGS 72BE / UTM zone 59S");
		SRID.put(32560, "WGS 72BE / UTM zone 60S");
		SRID.put(32601, "WGS 84 / UTM zone 1N");
		SRID.put(32602, "WGS 84 / UTM zone 2N");
		SRID.put(32603, "WGS 84 / UTM zone 3N");
		SRID.put(32604, "WGS 84 / UTM zone 4N");
		SRID.put(32605, "WGS 84 / UTM zone 5N");
		SRID.put(32606, "WGS 84 / UTM zone 6N");
		SRID.put(32607, "WGS 84 / UTM zone 7N");
		SRID.put(32608, "WGS 84 / UTM zone 8N");
		SRID.put(32609, "WGS 84 / UTM zone 9N");
		SRID.put(32610, "WGS 84 / UTM zone 10N");
		SRID.put(32611, "WGS 84 / UTM zone 11N");
		SRID.put(32612, "WGS 84 / UTM zone 12N");
		SRID.put(32613, "WGS 84 / UTM zone 13N");
		SRID.put(32614, "WGS 84 / UTM zone 14N");
		SRID.put(32615, "WGS 84 / UTM zone 15N");
		SRID.put(32616, "WGS 84 / UTM zone 16N");
		SRID.put(32617, "WGS 84 / UTM zone 17N");
		SRID.put(32618, "WGS 84 / UTM zone 18N");
		SRID.put(32619, "WGS 84 / UTM zone 19N");
		SRID.put(32620, "WGS 84 / UTM zone 20N");
		SRID.put(32621, "WGS 84 / UTM zone 21N");
		SRID.put(32622, "WGS 84 / UTM zone 22N");
		SRID.put(32623, "WGS 84 / UTM zone 23N");
		SRID.put(32624, "WGS 84 / UTM zone 24N");
		SRID.put(32625, "WGS 84 / UTM zone 25N");
		SRID.put(32626, "WGS 84 / UTM zone 26N");
		SRID.put(32627, "WGS 84 / UTM zone 27N");
		SRID.put(32628, "WGS 84 / UTM zone 28N");
		SRID.put(32629, "WGS 84 / UTM zone 29N");
		SRID.put(32630, "WGS 84 / UTM zone 30N");
		SRID.put(32631, "WGS 84 / UTM zone 31N");
		SRID.put(32632, "WGS 84 / UTM zone 32N");
		SRID.put(32633, "WGS 84 / UTM zone 33N");
		SRID.put(32634, "WGS 84 / UTM zone 34N");
		SRID.put(32635, "WGS 84 / UTM zone 35N");
		SRID.put(32636, "WGS 84 / UTM zone 36N");
		SRID.put(32637, "WGS 84 / UTM zone 37N");
		SRID.put(32638, "WGS 84 / UTM zone 38N");
		SRID.put(32639, "WGS 84 / UTM zone 39N");
		SRID.put(32640, "WGS 84 / UTM zone 40N");
		SRID.put(32641, "WGS 84 / UTM zone 41N");
		SRID.put(32642, "WGS 84 / UTM zone 42N");
		SRID.put(32643, "WGS 84 / UTM zone 43N");
		SRID.put(32644, "WGS 84 / UTM zone 44N");
		SRID.put(32645, "WGS 84 / UTM zone 45N");
		SRID.put(32646, "WGS 84 / UTM zone 46N");
		SRID.put(32647, "WGS 84 / UTM zone 47N");
		SRID.put(32648, "WGS 84 / UTM zone 48N");
		SRID.put(32649, "WGS 84 / UTM zone 49N");
		SRID.put(32650, "WGS 84 / UTM zone 50N");
		SRID.put(32651, "WGS 84 / UTM zone 51N");
		SRID.put(32652, "WGS 84 / UTM zone 52N");
		SRID.put(32653, "WGS 84 / UTM zone 53N");
		SRID.put(32654, "WGS 84 / UTM zone 54N");
		SRID.put(32655, "WGS 84 / UTM zone 55N");
		SRID.put(32656, "WGS 84 / UTM zone 56N");
		SRID.put(32657, "WGS 84 / UTM zone 57N");
		SRID.put(32658, "WGS 84 / UTM zone 58N");
		SRID.put(32659, "WGS 84 / UTM zone 59N");
		SRID.put(32660, "WGS 84 / UTM zone 60N");
		SRID.put(32701, "WGS 84 / UTM zone 1S");
		SRID.put(32702, "WGS 84 / UTM zone 2S");
		SRID.put(32703, "WGS 84 / UTM zone 3S");
		SRID.put(32704, "WGS 84 / UTM zone 4S");
		SRID.put(32705, "WGS 84 / UTM zone 5S");
		SRID.put(32706, "WGS 84 / UTM zone 6S");
		SRID.put(32707, "WGS 84 / UTM zone 7S");
		SRID.put(32708, "WGS 84 / UTM zone 8S");
		SRID.put(32709, "WGS 84 / UTM zone 9S");
		SRID.put(32710, "WGS 84 / UTM zone 10S");
		SRID.put(32711, "WGS 84 / UTM zone 11S");
		SRID.put(32712, "WGS 84 / UTM zone 12S");
		SRID.put(32713, "WGS 84 / UTM zone 13S");
		SRID.put(32714, "WGS 84 / UTM zone 14S");
		SRID.put(32715, "WGS 84 / UTM zone 15S");
		SRID.put(32716, "WGS 84 / UTM zone 16S");
		SRID.put(32717, "WGS 84 / UTM zone 17S");
		SRID.put(32718, "WGS 84 / UTM zone 18S");
		SRID.put(32719, "WGS 84 / UTM zone 19S");
		SRID.put(32720, "WGS 84 / UTM zone 20S");
		SRID.put(32721, "WGS 84 / UTM zone 21S");
		SRID.put(32722, "WGS 84 / UTM zone 22S");
		SRID.put(32723, "WGS 84 / UTM zone 23S");
		SRID.put(32724, "WGS 84 / UTM zone 24S");
		SRID.put(32725, "WGS 84 / UTM zone 25S");
		SRID.put(32726, "WGS 84 / UTM zone 26S");
		SRID.put(32727, "WGS 84 / UTM zone 27S");
		SRID.put(32728, "WGS 84 / UTM zone 28S");
		SRID.put(32729, "WGS 84 / UTM zone 29S");
		SRID.put(32730, "WGS 84 / UTM zone 30S");
		SRID.put(32731, "WGS 84 / UTM zone 31S");
		SRID.put(32732, "WGS 84 / UTM zone 32S");
		SRID.put(32733, "WGS 84 / UTM zone 33S");
		SRID.put(32734, "WGS 84 / UTM zone 34S");
		SRID.put(32735, "WGS 84 / UTM zone 35S");
		SRID.put(32736, "WGS 84 / UTM zone 36S");
		SRID.put(32737, "WGS 84 / UTM zone 37S");
		SRID.put(32738, "WGS 84 / UTM zone 38S");
		SRID.put(32739, "WGS 84 / UTM zone 39S");
		SRID.put(32740, "WGS 84 / UTM zone 40S");
		SRID.put(32741, "WGS 84 / UTM zone 41S");
		SRID.put(32742, "WGS 84 / UTM zone 42S");
		SRID.put(32743, "WGS 84 / UTM zone 43S");
		SRID.put(32744, "WGS 84 / UTM zone 44S");
		SRID.put(32745, "WGS 84 / UTM zone 45S");
		SRID.put(32746, "WGS 84 / UTM zone 46S");
		SRID.put(32747, "WGS 84 / UTM zone 47S");
		SRID.put(32748, "WGS 84 / UTM zone 48S");
		SRID.put(32749, "WGS 84 / UTM zone 49S");
		SRID.put(32750, "WGS 84 / UTM zone 50S");
		SRID.put(32751, "WGS 84 / UTM zone 51S");
		SRID.put(32752, "WGS 84 / UTM zone 52S");
		SRID.put(32753, "WGS 84 / UTM zone 53S");
		SRID.put(32754, "WGS 84 / UTM zone 54S");
		SRID.put(32755, "WGS 84 / UTM zone 55S");
		SRID.put(32756, "WGS 84 / UTM zone 56S");
		SRID.put(32757, "WGS 84 / UTM zone 57S");
		SRID.put(32758, "WGS 84 / UTM zone 58S");
		SRID.put(32759, "WGS 84 / UTM zone 59S");
		SRID.put(32760, "WGS 84 / UTM zone 60S");
		SRID.put(32766, "WGS 84 / TM 36 SE");

	}

	public static String getSridDescription(int srid) {
		String result = SRID.get(srid);
		if (result == null) {
			result = Db3dSimpleResourceBundle
					.getString("db3d.api.sridnotvalid");
		}
		return result;
	}

}
